summaryrefslogtreecommitdiff
path: root/Source/include
diff options
context:
space:
mode:
authorrichardbarry <richardbarry@1d2547de-c912-0410-9cb9-b8ca96c0e9e2>2008-04-16 07:47:02 +0000
committerrichardbarry <richardbarry@1d2547de-c912-0410-9cb9-b8ca96c0e9e2>2008-04-16 07:47:02 +0000
commitdff3073a024a2282ae7de1abb3806873113c668b (patch)
treec56e87282e165a416e8767be7e05cbff89f8a364 /Source/include
parent5f5dea9c5fd397545a9e6091eaf7efbad8631ce1 (diff)
downloadfreertos-dff3073a024a2282ae7de1abb3806873113c668b.tar.gz
freertos-dff3073a024a2282ae7de1abb3806873113c668b.tar.bz2
freertos-dff3073a024a2282ae7de1abb3806873113c668b.tar.xz
Update to V5.0.0.
git-svn-id: https://freertos.svn.sourceforge.net/svnroot/freertos/trunk@322 1d2547de-c912-0410-9cb9-b8ca96c0e9e2
Diffstat (limited to 'Source/include')
-rw-r--r--Source/include/FreeRTOS.h6
-rw-r--r--Source/include/croutine.h2
-rw-r--r--Source/include/list.h2
-rw-r--r--Source/include/portable.h2
-rw-r--r--Source/include/projdefs.h2
-rw-r--r--Source/include/queue.h7
-rw-r--r--Source/include/semphr.h6
-rw-r--r--Source/include/task.h6
8 files changed, 17 insertions, 16 deletions
diff --git a/Source/include/FreeRTOS.h b/Source/include/FreeRTOS.h
index f69fc02f..2e3069a9 100644
--- a/Source/include/FreeRTOS.h
+++ b/Source/include/FreeRTOS.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
@@ -128,8 +128,8 @@ typedef portBASE_TYPE (*pdTASK_HOOK_CODE)( void * );
#error Missing definition: configUSE_16_BIT_TICKS should be defined in FreeRTOSConfig.h as either 1 or 0. See the Configuration section of the FreeRTOS API documentation for details.
#endif
-#ifndef configUSE_APPLICATION_TASK_HOOK
- #define configUSE_APPLICATION_TASK_HOOK 0
+#ifndef configUSE_APPLICATION_TASK_TAG
+ #define configUSE_APPLICATION_TASK_TAG 0
#endif
#ifndef INCLUDE_uxTaskGetStackHighWaterMark
diff --git a/Source/include/croutine.h b/Source/include/croutine.h
index 8cad64b4..669baee9 100644
--- a/Source/include/croutine.h
+++ b/Source/include/croutine.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
diff --git a/Source/include/list.h b/Source/include/list.h
index 5dd6cad1..b6df2f38 100644
--- a/Source/include/list.h
+++ b/Source/include/list.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
diff --git a/Source/include/portable.h b/Source/include/portable.h
index 926396ac..eae4e704 100644
--- a/Source/include/portable.h
+++ b/Source/include/portable.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
diff --git a/Source/include/projdefs.h b/Source/include/projdefs.h
index 9b78d4e7..6aac83a8 100644
--- a/Source/include/projdefs.h
+++ b/Source/include/projdefs.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
diff --git a/Source/include/queue.h b/Source/include/queue.h
index 5d17508e..8cafe67a 100644
--- a/Source/include/queue.h
+++ b/Source/include/queue.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
@@ -960,14 +960,15 @@ void vQueueDelete( xQueueHandle xQueue );
cIn = portINPUT_BYTE( RX_REGISTER_ADDRESS );
// Post the byte.
- xTaskWokenByPost = xQueueSendFromISR( xRxQueue, &cIn, &xHigherPriorityTaskWoken );
+ xQueueSendFromISR( xRxQueue, &cIn, &xHigherPriorityTaskWoken );
} while( portINPUT_BYTE( BUFFER_COUNT ) );
// Now the buffer is empty we can switch context if necessary.
if( xHigherPriorityTaskWoken )
{
- taskYIELD ();
+ // Actual macro used here is port specific.
+ taskYIELD_FROM_ISR ();
}
}
</pre>
diff --git a/Source/include/semphr.h b/Source/include/semphr.h
index accfa41a..b9339be8 100644
--- a/Source/include/semphr.h
+++ b/Source/include/semphr.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
@@ -446,7 +446,7 @@ typedef xQueueHandle xSemaphoreHandle;
* <pre>
xSemaphoreGiveFromISR(
xSemaphoreHandle xSemaphore,
- portSHORT sTaskPreviouslyWoken
+ portBASE_TYPE *pxHigherPriorityTaskWoken
)</pre>
*
* <i>Macro</i> to release a semaphore. The semaphore must have previously been
@@ -461,7 +461,7 @@ typedef xQueueHandle xSemaphoreHandle;
* handle returned when the semaphore was created.
*
* @param pxHigherPriorityTaskWoken xSemaphoreGiveFromISR() will set
- * *pxHigherPriorityTaskWoken to pdTRUE if sending to the queue caused a task
+ * *pxHigherPriorityTaskWoken to pdTRUE if giving the semaphore caused a task
* to unblock, and the unblocked task has a priority higher than the currently
* running task. If xSemaphoreGiveFromISR() sets this value to pdTRUE then
* a context switch should be requested before the interrupt is exited.
diff --git a/Source/include/task.h b/Source/include/task.h
index 23411839..bb0cc225 100644
--- a/Source/include/task.h
+++ b/Source/include/task.h
@@ -1,5 +1,5 @@
/*
- FreeRTOS.org V4.8.0 - Copyright (C) 2003-2008 Richard Barry.
+ FreeRTOS.org V5.0.0 - Copyright (C) 2003-2008 Richard Barry.
This file is part of the FreeRTOS.org distribution.
@@ -895,13 +895,13 @@ unsigned portBASE_TYPE uxTaskGetStackHighWaterMark( xTaskHandle xTask );
/**
* task.h
* <pre>void vTaskSetApplicationTaskHook( xTaskHandle xTask, pdTASK_HOOK_CODE pxHookFunction );</pre>
*
* Sets pxHookFunction to be the task hook function used by the task xTask.
* Passing xTask as NULL has the effect of setting the calling tasks hook
* function.
*/
-void vTaskSetApplicationTaskHook( xTaskHandle xTask, pdTASK_HOOK_CODE pxHookFunction );
+void vTaskSetApplicationTaskTag( xTaskHandle xTask, pdTASK_HOOK_CODE pxHookFunction );
/**
* task.h
@@ -895,13 +895,13 @@ unsigned portBASE_TYPE uxTaskGetStackHighWaterMark( xTaskHandle xTask );
/**
* task.h
- * <pre>void vTaskSetApplicationTaskHook( xTaskHandle xTask, pdTASK_HOOK_CODE pxHookFunction );</pre>
+ * <pre>void vTaskSetApplicationTaskTag( xTaskHandle xTask, pdTASK_HOOK_CODE pxHookFunction );</pre>
*
* Sets pxHookFunction to be the task hook function used by the task xTask.